:: taz-3-9-config-backup.bat
:: Sicherungskopie der Einstellungen der TransAlarm-Zentrale (3.9.x)
:: Version 4, 2021-07-15, peu
@echo off

setlocal

set _TMP_TAZBAK=%TMP%\TAZBAK
set "appInfix="
set "ySwitch=/y"
set "virtCheck=ON"

:: Windows-Version ermitteln:
for /f "tokens=4-5 delims=.XP " %%i in ('ver') do set VERSION=%%i.%%j
if "%version%" == "10.0" echo Windows 10 && goto bits
if "%version%" == "6.3" echo Windows 8.1 && goto bits
if "%version%" == "6.2" echo Windows 8. && goto bits
if "%version%" == "6.1" echo Windows 7. && goto bits
if "%version%" == "6.0" echo Windows Vista. && goto bits
if "%version%" == "5.1" (
echo Windows XP.
set "appInfix=\Anwendungsdaten"
set "ySwitch="
set "virtCheck=OFF"
goto bits
)

:: Problem: Info kann nicht ermittelt werden:
echo FEHLER. Unbekannt: Version %version%
echo Analyse wird abgebrochen
goto end

:bits

:: Bittigkeit des Betriebssystems ermitteln:
reg query "HKLM\Hardware\Description\System\CentralProcessor\0" | find /i "x86" > NUL && set OS=32BIT || set OS=64BIT
if %OS%==32BIT echo 32bit OS && set "prog32=%programfiles%" && goto bits_done
if %OS%==64BIT echo 64bit OS && set "prog32=%programfiles(x86)%" && goto bits_done

:: Problem: Info kann nicht ermittelt werden:
echo FEHLER. Interner Fehler bei Analyse der Bittigkeit (x86, x64)
echo Analyse wird abgebrochen
goto end

:bits_done

:: Temporaere Verzeichnisse erstellen:
mkdir %_TMP_TAZBAK%
mkdir %_TMP_TAZBAK%\Registry
mkdir %_TMP_TAZBAK%\InstallDir
mkdir %_TMP_TAZBAK%\AllUsersProfile

:registry

:: Konfigurationsanteile aus Registrierung extrahieren:
set "reg32opt="
:: bei 64-bit-Systemen liegen 32-bit-Anwendungen auf speziellem Zweig:
if %OS%==64BIT set "reg32opt=/reg:32"

reg export HKEY_CURRENT_USER\Software\REKOBA %_TMP_TAZBAK%\Registry\HKCU-REKOBA.reg.txt %ySwitch% %reg32opt% >NUL 2>&1
reg export HKEY_LOCAL_MACHINE\SOFTWARE\REKOBA %_TMP_TAZBAK%\Registry\HKLM-REKOBA.reg.txt %ySwitch% %reg32opt% >NUL 2>&1

:summary

echo prog32: "%prog32%"

:: Beispiel fuer "Anwendung", die auf allen Rechnern existiert:
set "appName=TransAlarm"
set "profName=REKOBA\TransAlarm"

set "installfolder=%prog32%\%appName%"
echo installfolder: "%installfolder%"

:: Konfigurationsanteile (2 Dateien) aus Installationsordner kopieren:
if exist "%installfolder%" echo %appName%-Installfolder "%installfolder%" was found.
if not exist "%installfolder%" goto skip_copy_inst
copy "%installfolder%\report-schablone1.*" %_TMP_TAZBAK%\InstallDir
copy "%installfolder%\*.ini" %_TMP_TAZBAK%\InstallDir

:skip_copy_inst

set "tazprofile=%allusersprofile%%appInfix%\%profName%"
echo tazprofile: "%tazprofile%"

if exist "%tazprofile%" echo %profName%-Profile "%tazprofile%" was found.
if not exist "%tazprofile%" goto done_profile
:: Konfigurationsanteile aus dem "Profil" fuer alle Anwender kopieren:
xcopy "%tazprofile%\Config\*" %_TMP_TAZBAK%\AllUsersProfile\REKOBA\TransAlarm\Config /S /I

:done_profile

:: Fertig mit dem Extrahieren:
echo .
echo Konfiguration ohne Fehler ermittelt.
echo .

:: Der Zip-Archiv-Name setzt sich zusammen aus einem festen Praefix,
:: dem Computernamen und dem Zeitpunkt des Abgriffs; wir brauchen den
:: absoluten Pfad zu dieser (noch nicht vorhandenen) Datei:
for /f %%G in ('cscript /nologo %~dp0timestamp.vbs') do set _mytimestamp=%%G
set _ARCHIVE_FILENAME=taz-3-9-conf-%computername%-%_mytimestamp%-bak.zip
set _ARCHIVE=%~dp0%_ARCHIVE_FILENAME%

:: Absoluter Pfad zum 7-Zip-Programm:
set _7ZIP=%~dp07-zip\7za

:: Wir gehen in den temporaeren Ordner, um im Zip-Archiv 
:: die lokale Ordner-Struktur erzeugen zu koennen:
pushd %_TMP_TAZBAK%

:: Extrahierten Konfigurationsanteile ins Zip-Archiv uebernehmen:
%_7ZIP% a %_ARCHIVE% Registry\
%_7ZIP% a %_ARCHIVE% InstallDir\
%_7ZIP% a %_ARCHIVE% AllUsersProfile\

popd

:: Temopraere Verzeichnisse loeschen:
rmdir %_TMP_TAZBAK%\AllUsersProfile /s /q
rmdir %_TMP_TAZBAK%\InstallDir /s /q
rmdir %_TMP_TAZBAK%\Registry /s /q
rmdir %_TMP_TAZBAK% /s /q

:: Hilfsskript (fuer "als Administrator ausfuehren" per Linksklick):
set "_RESTORE_HELPER=%~dp0taz-restore-%computername%-%_mytimestamp%.bat"
echo @echo off > "%_RESTORE_HELPER%"
echo pushd "%%~dp0" >> "%_RESTORE_HELPER%"
echo call taz-3-9-config-restore.bat "%_ARCHIVE_FILENAME%" >> "%_RESTORE_HELPER%"
echo popd >> "%_RESTORE_HELPER%"
echo pause >> "%_RESTORE_HELPER%"

:end

endlocal

pause
echo on
